import Link from "next/link"
import Image from "next/image"

export default function Footer() {
  const currentYear = new Date().getFullYear()

  return (
    <footer className="bg-background border-t border-white/10 relative">
      <div className="absolute inset-0 grid-pattern opacity-10" />

      <div className="container mx-auto px-4 py-12 relative z-10">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
          <div className="md:col-span-1">
            <Link href="/" className="flex items-center gap-2 mb-4">
              <Image src="/logo.svg" alt="Simba Robotics Logo" width={40} height={40} className="w-10 h-10" />
              <div className="flex flex-col">
                <span className="font-bold text-lg tracking-wider">SIMBA</span>
                <span className="text-xs text-muted-foreground font-mono">ROBOTICS</span>
              </div>
            </Link>
            <p className="text-sm text-muted-foreground leading-relaxed">
              黑龙江大学 602 创新实验室，主要参加 RoboMaster 系列比赛。
            </p>
          </div>

          <div>
            <h3 className="font-bold mb-4 text-primary text-sm font-mono">QUICK LINKS</h3>
            <ul className="space-y-2">
              <li>
                <Link href="#home" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  主页
                </Link>
              </li>
              <li>
                <Link href="#about" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  关于
                </Link>
              </li>
              <li>
                <Link
                  href="#team-groups"
                  className="text-sm text-muted-foreground hover:text-primary transition-colors"
                >
                  团队
                </Link>
              </li>
              <li>
                <Link
                  href="#achievements"
                  className="text-sm text-muted-foreground hover:text-primary transition-colors"
                >
                  成就
                </Link>
              </li>
              <li>
                <Link href="#robots" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  机器人
                </Link>
              </li>
              <li>
                <Link href="#contact" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  联系我们
                </Link>
              </li>
            </ul>
          </div>

          <div>
            <h3 className="font-bold mb-4 text-primary text-sm font-mono">RESOURCES</h3>
            <ul className="space-y-2">
              <li>
                <Link href="#" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  RoboMaster 官方网站
                </Link>
              </li>
              <li>
                <Link href="#" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  技术文档
                </Link>
              </li>
              <li>
                <Link href="#" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  战队手册
                </Link>
              </li>
              <li>
                <Link href="#" className="text-sm text-muted-foreground hover:text-primary transition-colors">
                  关注我们
                </Link>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-white/10 mt-12 pt-6 flex flex-col md:flex-row justify-between items-center">
          <p className="text-sm text-muted-foreground">© {currentYear} Simba Robotics. 保留一切权利。</p>
          <div className="flex gap-4 mt-4 md:mt-0">
            <Link href="#" className="text-xs text-muted-foreground hover:text-primary transition-colors">
              隐私政策
            </Link>
            <Link href="#" className="text-xs text-muted-foreground hover:text-primary transition-colors">
              服务条款
            </Link>
          </div>
        </div>
      </div>
    </footer>
  )
}
